utils::globalVariables(
  names = c(
    "fa1",
    "fa2",
    "Vg",
    "BLUE",
    "site",
    "x",
    "y",
    "vx",
    "vy",
    "blup",
    ".",
    "Score",
    "Genotype",
    "value",
    "total",
    "percent",
    "SD",
    "Mean",
    "n_miss",
    "gen_reps",
    "n_gen",
    "n_rep",
    "rcbd",
    "n_block",
    "num_of_reps",
    "n_col",
    "n_row",
    "miss_perc",
    "var_total",
    "spatial",
    "prep",
    "exp_design",
    "solution",
    "std.error",
    "Var2",
    "Var1",
    "fa1_scaled",
    "fa2_scaled",
    "name.x",
    "label",
    "Effect",
    "Line",
    "predicted.value",
    "Ls",
    "Lu",
    "predicted.values",
    "standard.errors",
    "checks",
    "r_square",
    "Classify",
    "fit",
    "Residuals",
    "Index",
    "..density..",
    "alpha_lattice",
    "trial",
    ":=",
    "genotype",
    "coef",
    "CV_spats",
    "outlier",
    "seBLUEs",
    "residual",
    "mean_gen",
    "mean_trial",
    "wt",
    "trait",
    "heritability",
    "trial_y",
    "trial_x",
    "size_reps",
    "reps_equal",
    "BLUPs",
    "component",
    "design"
  )
)
